import { defineConfig, loadEnv } from 'vite'
import path from 'path'
import createVitePlugins from './vite/plugins'

// https://vitejs.dev/config/
export default defineConfig(({ mode, command }) => {
  const env = loadEnv(mode, process.cwd())
  const { VITE_APP_ENV } = env
  return {
    // 部署生产环境和开发环境下的URL。
    // 默认情况下，vite 会假设你的应用是被部署在一个域名的根路径上
    // 例如 https://www.ezhizao.cn/。如果应用被部署在一个子路径上，你就需要用这个选项指定这个子路径。例如，如果你的应用被部署在 https://www.ezhizao.cn/admin/，则设置 baseUrl 为 /admin/。
    base: VITE_APP_ENV === 'production' ? '/' : '/',
    plugins: createVitePlugins(env, command === 'build'),
    resolve: {
      // https://cn.vitejs.dev/config/#resolve-alias
      alias: {
        // 设置路径
        '~': path.resolve(__dirname, './'),
        // 设置别名
        '@': path.resolve(__dirname, './src')
      },
      // https://cn.vitejs.dev/config/#resolve-extensions
      extensions: ['.mjs', '.js', '.ts', '.jsx', '.tsx', '.json', '.vue']
    },
    // vite 相关配置
    server: {
      port: 81,
      host: true,
      open: true,
      proxy: {
        // https://cn.vitejs.dev/config/#server-proxy
        '/ezhizao-dms-sys': {
          target: 'http://localhost:8080',
          changeOrigin: true,
          rewrite: (p) => p.replace(/^\/ezhizao-dms-sys/, '')
        },
        // 生产管理配置示例
        '/ezhizao-dms-production': {
          target: 'http://localhost:8081',
          changeOrigin: true,
          rewrite: (p) => p.replace(/^\/ezhizao-dms-production/, '')
        },
        // 生产报工配置
        '/ezhizao-dms-p2': {
          target: 'http://localhost:8098',
          changeOrigin: true,
          rewrite: (p) => p.replace(/^\/ezhizao-dms-p2/, '')
        },
        '/ws-sys': {
          target: 'ws://localhost:8080/wsMessage',
          changeOrigin: true,
          rewrite: (p) => p.replace(/^\/ws-sys/, ''),
          ws: true
        },
        '/ws-production': {
          target: 'ws://localhost:8080/wsExport',
          changeOrigin: true,
          rewrite: (p) => p.replace(/^\/ws-production/, ''),
          ws: true
        },
        '/ezhizao-dms-jd': {
          target: 'http://localhost:8083',
          changeOrigin: true,
          rewrite: (p) => p.replace(/^\/ezhizao-dms-jd/, '')
        }
      }
    },
    //fix:error:stdin>:7356:1: warning: "@charset" must be the first rule in the file
    css: {
      postcss: {
        plugins: [
          {
            postcssPlugin: 'internal:charset-removal',
            AtRule: {
              charset: (atRule) => {
                if (atRule.name === 'charset') {
                  atRule.remove()
                }
              }
            }
          }
        ]
      }
    },
    esbuild: {
      jsxFactory: 'h',
      jsxFragment: 'Fragment',
      // jsxInject: `import { h } from 'vue';`,
    }
  }
})
